# Changelog

## [Unreleased]

## [2.0.0-beta.6] - 2025-10-25

Incomplete beta release.

## [2.0.0-beta.5] - 2025-10-24

Incomplete beta release.

## [2.0.0-beta.4] - 2025-10-18

Incomplete beta release.

## [2.0.0-beta.3] - 2025-10-18

Incomplete beta release.

## [2.0.0-beta.2] - 2025-10-12

Incomplete beta release.

## [2.0.0-beta.1] - 2024-11-20

Incomplete beta release.

## [2.0.0-beta.0] - 2024-08-29

Incomplete beta release.

## [1.1.0] - 2022-06-30

Outdated release.

## [1.0.1] - 2022-02-08

Outdated release.

## [1.0.0] - 2022-02-08

Outdated release.

## [0.0.6] - 2022-02-05

## [0.0.4] - 2022-02-03

## [0.0.3] - 2022-02-03

[0.0.3]: https://github.com/taminomara/yuio/releases/tag/v0.0.3
[0.0.4]: https://github.com/taminomara/yuio/compare/v0.0.3...v0.0.4
[0.0.6]: https://github.com/taminomara/yuio/compare/v0.0.4...v0.0.6
[1.0.0]: https://github.com/taminomara/yuio/compare/v0.0.6...v1.0.0
[1.0.1]: https://github.com/taminomara/yuio/compare/v1.0.0...v1.0.1
[1.1.0]: https://github.com/taminomara/yuio/compare/v1.0.1...v1.1.0
[2.0.0-beta.0]: https://github.com/taminomara/yuio/compare/v1.1.0...v2.0.0-beta.0
[2.0.0-beta.1]: https://github.com/taminomara/yuio/compare/v2.0.0-beta.0...v2.0.0-beta.1
[2.0.0-beta.2]: https://github.com/taminomara/yuio/compare/v2.0.0-beta.1...v2.0.0-beta.2
[2.0.0-beta.3]: https://github.com/taminomara/yuio/compare/v2.0.0-beta.2...v2.0.0-beta.3
[2.0.0-beta.4]: https://github.com/taminomara/yuio/compare/v2.0.0-beta.3...v2.0.0-beta.4
[2.0.0-beta.5]: https://github.com/taminomara/yuio/compare/v2.0.0-beta.4...v2.0.0-beta.5
[unreleased]: https://github.com/taminomara/yuio/compare/v2.0.0-beta.5...HEAD
